@@ -81,8 +81,12 @@ static void     caja_information_panel_drag_data_received    (GtkWidget
         guint                         info,
         guint                         time);
 static void     caja_information_panel_read_defaults         (CajaInformationPanel     *information_panel);
+#if GTK_CHECK_VERSION (3, 0, 0)
+static void     caja_information_panel_style_updated         (GtkWidget                    *widget);
+#else
 static void     caja_information_panel_style_set             (GtkWidget                    *widget,
         GtkStyle                     *previous_style);
+#endif
 static void     caja_information_panel_theme_changed         (GSettings   *settings,
                                                               const gchar *key,
                                                               gpointer     user_data);
@@ -206,7 +210,11 @@ caja_information_panel_class_init (CajaInformationPanelClass *klass)
 
     widget_class->drag_data_received  = caja_information_panel_drag_data_received;
     widget_class->button_press_event  = caja_information_panel_press_event;
+#if GTK_CHECK_VERSION (3, 0, 0)
+    widget_class->style_updated = caja_information_panel_style_updated;
+#else
     widget_class->style_set = caja_information_panel_style_set;
+#endif
 
     /* add the "location changed" signal */
     signals[LOCATION_CHANGED] = g_signal_new
@@ -1174,7 +1182,11 @@ title_changed_callback (CajaWindowInfo *window,
 
 /* ::style_set handler for the information_panel */
 static void
+#if GTK_CHECK_VERSION (3, 0, 0)
+caja_information_panel_style_updated (GtkWidget *widget)
+#else
 caja_information_panel_style_set (GtkWidget *widget, GtkStyle *previous_style)
+#endif
 {
     CajaInformationPanel *information_panel;
 
