@@ -140,8 +140,12 @@ static void     caja_path_bar_grab_notify              (GtkWidget       *widget,
         gboolean         was_grabbed);
 static void     caja_path_bar_state_changed            (GtkWidget       *widget,
         GtkStateType     previous_state);
+#if GTK_CHECK_VERSION (3, 0, 0)
+static void     caja_path_bar_style_updated            (GtkWidget       *widget);
+#else
 static void     caja_path_bar_style_set                (GtkWidget       *widget,
         GtkStyle        *previous_style);
+#endif
 static void     caja_path_bar_screen_changed           (GtkWidget       *widget,
         GdkScreen       *previous_screen);
 static void     caja_path_bar_check_icon_theme         (CajaPathBar *path_bar);
@@ -401,7 +405,11 @@ caja_path_bar_class_init (CajaPathBarClass *path_bar_class)
 #endif
     widget_class->unmap = caja_path_bar_unmap;
     widget_class->size_allocate = caja_path_bar_size_allocate;
+#if GTK_CHECK_VERSION (3, 0, 0)
+    widget_class->style_updated = caja_path_bar_style_updated;
+#else
     widget_class->style_set = caja_path_bar_style_set;
+#endif
     widget_class->screen_changed = caja_path_bar_screen_changed;
     widget_class->grab_notify = caja_path_bar_grab_notify;
     widget_class->state_changed = caja_path_bar_state_changed;
@@ -957,11 +965,19 @@ caja_path_bar_size_allocate (GtkWidget     *widget,
 }
 
 static void
+#if GTK_CHECK_VERSION (3, 0, 0)
+caja_path_bar_style_updated (GtkWidget *widget)
+{
+    if (GTK_WIDGET_CLASS (caja_path_bar_parent_class)->style_updated)
+    {
+        GTK_WIDGET_CLASS (caja_path_bar_parent_class)->style_updated (widget);
+#else
 caja_path_bar_style_set (GtkWidget *widget,	GtkStyle  *previous_style)
 {
     if (GTK_WIDGET_CLASS (caja_path_bar_parent_class)->style_set)
     {
         GTK_WIDGET_CLASS (caja_path_bar_parent_class)->style_set (widget, previous_style);
+#endif
     }
 
     caja_path_bar_check_icon_theme (CAJA_PATH_BAR (widget));
